==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/DescribeProgramRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeProgramRequest(
    channelName: __string,
    programName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest = {
    import DescribeProgramRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .programName(__string.unwrap(programName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DescribeProgramRequest.ReadOnly =
    zio.aws.mediatailor.model.DescribeProgramRequest.wrap(buildAwsValue())
}
object DescribeProgramRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DescribeProgramRequest =
      zio.aws.mediatailor.model.DescribeProgramRequest(channelName, programName)
    def channelName: __string
    def programName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
    def getProgramName: ZIO[Any, Nothing, __string] = ZIO.succeed(programName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest
  ) extends zio.aws.mediatailor.model.DescribeProgramRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
    override val programName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.programName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest
  ): zio.aws.mediatailor.model.DescribeProgramRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-5.17.217.1-sources.jar: zio/aws/mediatailor/model/DescribeProgramRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DescribeProgramRequest(
    channelName: __string,
    programName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest = {
    import DescribeProgramRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .programName(programName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DescribeProgramRequest.ReadOnly =
    zio.aws.mediatailor.model.DescribeProgramRequest.wrap(buildAwsValue())
}
object DescribeProgramRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DescribeProgramRequest =
      zio.aws.mediatailor.model.DescribeProgramRequest(channelName, programName)
    def channelName: __string
    def programName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
    def getProgramName: ZIO[Any, Nothing, __string] = ZIO.succeed(programName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest
  ) extends zio.aws.mediatailor.model.DescribeProgramRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
    override val programName: __string = impl.programName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DescribeProgramRequest
  ): zio.aws.mediatailor.model.DescribeProgramRequest.ReadOnly = new Wrapper(
    impl
  )
}
